==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/e8/e8e0edb48a58e5e7d1f939b99b9f9e9b.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Event/CustomAssetsEvent.php */
class __TwigTemplate_6d76c2fff738b610679aebacb52cc923 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\Event;

use Mautic\\CoreBundle\\Twig\\Helper\\AssetsHelper;
use Symfony\\Contracts\\EventDispatcher\\Event;

class CustomAssetsEvent extends Event
{
    public function __construct(
        protected AssetsHelper \$assetsHelper
    ) {
    }

    /**
     * @param string \$location
     * @param string \$context
     */
    public function addCustomDeclaration(\$declaration, \$location = 'head', \$context = AssetsHelper::CONTEXT_APP)
    {
        \$this->assetsHelper->setContext(\$context)
            ->addCustomDeclaration(\$declaration, \$location)
            ->setContext(AssetsHelper::CONTEXT_APP);

        return \$this;
    }

    /**
     * @param string \$location
     * @param bool   \$async
     * @param string \$context
     */
    public function addScript(\$script, \$location = 'head', \$async = false, \$name = null, \$context = AssetsHelper::CONTEXT_APP)
    {
        \$this->assetsHelper->setContext(\$context)
            ->addScript(\$script, \$location, \$async, \$name)
            ->setContext(AssetsHelper::CONTEXT_APP);

        return \$this;
    }

    /**
     * @param string \$location
     * @param string \$context
     */
    public function addScriptDeclaration(\$script, \$location = 'head', \$context = AssetsHelper::CONTEXT_APP)
    {
        \$this->assetsHelper->setContext(\$context)
            ->addScriptDeclaration(\$script, \$location)
            ->setContext(AssetsHelper::CONTEXT_APP);

        return \$this;
    }

    /**
     * @param string \$context
     */
    public function addStylesheet(\$stylesheet, \$context = AssetsHelper::CONTEXT_APP)
    {
        \$this->assetsHelper->setContext(\$context)
            ->addStylesheet(\$stylesheet)
            ->setContext(AssetsHelper::CONTEXT_APP);

        return \$this;
    }

    /**
     * @param string \$context
     */
    public function addStyleDeclaration(\$styles, \$context = AssetsHelper::CONTEXT_APP)
    {
        \$this->assetsHelper->setContext(\$context)
            ->addStyleDeclaration(\$styles)
            ->setContext(AssetsHelper::CONTEXT_APP);

        return \$this;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Event/CustomAssetsEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Event/CustomAssetsEvent.php", "/var/www/mautic-ktn/app/bundles/CoreBundle/Event/CustomAssetsEvent.php");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/e8/e8e0edb48a58e5e7d1f939b99b9f9e9b.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Event/CustomAssetsEvent.php */
class __TwigTemplate_6d76c2fff738b610679aebacb52cc923 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\Event;

use Mautic\\CoreBundle\\Twig\\Helper\\AssetsHelper;
use Symfony\\Contracts\\EventDispatcher\\Event;

class CustomAssetsEvent extends Event
{
    public function __construct(
        protected AssetsHelper \$assetsHelper
    ) {
    }

    /**
     * @param string \$location
     * @param string \$context
     */
    public function addCustomDeclaration(\$declaration, \$location = 'head', \$context = AssetsHelper::CONTEXT_APP)
    {
        \$this->assetsHelper->setContext(\$context)
            ->addCustomDeclaration(\$declaration, \$location)
            ->setContext(AssetsHelper::CONTEXT_APP);

        return \$this;
    }

    /**
     * @param string \$location
     * @param bool   \$async
     * @param string \$context
     */
    public function addScript(\$script, \$location = 'head', \$async = false, \$name = null, \$context = AssetsHelper::CONTEXT_APP)
    {
        \$this->assetsHelper->setContext(\$context)
            ->addScript(\$script, \$location, \$async, \$name)
            ->setContext(AssetsHelper::CONTEXT_APP);

        return \$this;
    }

    /**
     * @param string \$location
     * @param string \$context
     */
    public function addScriptDeclaration(\$script, \$location = 'head', \$context = AssetsHelper::CONTEXT_APP)
    {
        \$this->assetsHelper->setContext(\$context)
            ->addScriptDeclaration(\$script, \$location)
            ->setContext(AssetsHelper::CONTEXT_APP);

        return \$this;
    }

    /**
     * @param string \$context
     */
    public function addStylesheet(\$stylesheet, \$context = AssetsHelper::CONTEXT_APP)
    {
        \$this->assetsHelper->setContext(\$context)
            ->addStylesheet(\$stylesheet)
            ->setContext(AssetsHelper::CONTEXT_APP);

        return \$this;
    }

    /**
     * @param string \$context
     */
    public function addStyleDeclaration(\$styles, \$context = AssetsHelper::CONTEXT_APP)
    {
        \$this->assetsHelper->setContext(\$context)
            ->addStyleDeclaration(\$styles)
            ->setContext(AssetsHelper::CONTEXT_APP);

        return \$this;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Event/CustomAssetsEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Event/CustomAssetsEvent.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Event/CustomAssetsEvent.php");
    }
}
